package system

//NOTES:
//* syscall constants in the "syscall" package are nice, but some syscalls there are missing
//* future versions will include more than just the syscall name
//* 32bit (x86/i386) and 64bit (x86_64) syscall numbers are different

const (
	SyscallX86MinNum      = 0
	SyscallX86UnknownNum  = -1
	SyscallX86UnknownName = "unknown_syscall"

	SyscallX86MaxNum32   = 358
	SyscallX86LastName32 = "execveat"

	SyscallX86MaxNum64   = 322
	SyscallX86LastName64 = "execveat"

	SyscallArmUnknownNum  = -1
	SyscallArmUnknownName = "unknown_syscall"
	SyscallArmMinNum32    = 0
	SyscallArmMaxNum32    = 377
	SyscallArmLastName32  = "process_vm_writev"
)

type NumberResolverFunc func(int16) string

func CallNumberResolver(arch ArchName) NumberResolverFunc {
	switch arch {
	case ArchName386:
		return callNameX86Family32
	case ArchNameAmd64:
		return callNameX86Family64
	case ArchNameArm32:
		return callNameArmFamily32
	default:
		return nil
	}
}

var syscallNumTableX86Family64 = [...]string{
	"read",
	"write",
	"open",
	"close",
	"stat",
	"fstat",
	"lstat",
	"poll",
	"lseek",
	"mmap",
	"mprotect",
	"munmap",
	"brk",
	"rt_sigaction",
	"rt_sigprocmask",
	"rt_sigreturn",
	"ioctl",
	"pread",
	"pwrite",
	"readv",
	"writev",
	"access",
	"pipe",
	"select",
	"sched_yield",
	"mremap",
	"msync",
	"mincore",
	"madvise",
	"shmget",
	"shmat",
	"shmctl",
	"dup",
	"dup2",
	"pause",
	"nanosleep",
	"getitimer",
	"alarm",
	"setitimer",
	"getpid",
	"sendfile",
	"socket",
	"connect",
	"accept",
	"sendto",
	"recvfrom",
	"sendmsg",
	"recvmsg",
	"shutdown",
	"bind",
	"listen",
	"getsockname",
	"getpeername",
	"socketpair",
	"setsockopt",
	"getsockopt",
	"clone",
	"fork",
	"vfork",
	"execve",
	"_exit",
	"wait4",
	"kill",
	"uname",
	"semget",
	"semop",
	"semctl",
	"shmdt",
	"msgget",
	"msgsnd",
	"msgrcv",
	"msgctl",
	"fcntl",
	"flock",
	"fsync",
	"fdatasync",
	"truncate",
	"ftruncate",
	"getdents",
	"getcwd",
	"chdir",
	"fchdir",
	"rename",
	"mkdir",
	"rmdir",
	"creat",
	"link",
	"unlink",
	"symlink",
	"readlink",
	"chmod",
	"fchmod",
	"chown",
	"fchown",
	"lchown",
	"umask",
	"gettimeofday",
	"getrlimit",
	"getrusage",
	"sysinfo",
	"times",
	"ptrace",
	"getuid",
	"syslog",
	"getgid",
	"setuid",
	"setgid",
	"geteuid",
	"getegid",
	"setpgid",
	"getppid",
	"getpgrp",
	"setsid",
	"setreuid",
	"setregid",
	"getgroups",
	"setgroups",
	"setresuid",
	"getresuid",
	"setresgid",
	"getresgid",
	"getpgid",
	"setfsuid",
	"setfsgid",
	"getsid",
	"capget",
	"capset",
	"rt_sigpending",
	"rt_sigtimedwait",
	"rt_sigqueueinfo",
	"rt_sigsuspend",
	"sigaltstack",
	"utime",
	"mknod",
	"uselib",
	"personality",
	"ustat",
	"statfs",
	"fstatfs",
	"sysfs",
	"getpriority",
	"setpriority",
	"sched_setparam",
	"sched_getparam",
	"sched_setscheduler",
	"sched_getscheduler",
	"sched_get_priority_max",
	"sched_get_priority_min",
	"sched_rr_get_interval",
	"mlock",
	"munlock",
	"mlockall",
	"munlockall",
	"vhangup",
	"modify_ldt",
	"pivot_root",
	"_sysctl",
	"prctl",
	"arch_prctl",
	"adjtimex",
	"setrlimit",
	"chroot",
	"sync",
	"acct",
	"settimeofday",
	"mount",
	"umount2",
	"swapon",
	"swapoff",
	"reboot",
	"sethostname",
	"setdomainname",
	"iopl",
	"ioperm",
	"create_module",
	"init_module",
	"delete_module",
	"get_kernel_syms",
	"query_module",
	"quotactl",
	"nfsservctl",
	"getpmsg",
	"putpmsg",
	"afs_syscall",
	"tuxcall",
	"security",
	"gettid",
	"readahead",
	"setxattr",
	"lsetxattr",
	"fsetxattr",
	"getxattr",
	"lgetxattr",
	"fgetxattr",
	"listxattr",
	"llistxattr",
	"flistxattr",
	"removexattr",
	"lremovexattr",
	"fremovexattr",
	"tkill",
	"time",
	"futex",
	"sched_setaffinity",
	"sched_getaffinity",
	"set_thread_area",
	"io_setup",
	"io_destroy",
	"io_getevents",
	"io_submit",
	"io_cancel",
	"get_thread_area",
	"lookup_dcookie",
	"epoll_create",
	"epoll_ctl_old",
	"epoll_wait_old",
	"remap_file_pages",
	"getdents64",
	"set_tid_address",
	"restart_syscall",
	"semtimedop",
	"fadvise64",
	"timer_create",
	"timer_settime",
	"timer_gettime",
	"timer_getoverrun",
	"timer_delete",
	"clock_settime",
	"clock_gettime",
	"clock_getres",
	"clock_nanosleep",
	"exit_group",
	"epoll_wait",
	"epoll_ctl",
	"tgkill",
	"utimes",
	"vserver",
	"mbind",
	"set_mempolicy",
	"get_mempolicy",
	"mq_open",
	"mq_unlink",
	"mq_timedsend",
	"mq_timedreceive",
	"mq_notify",
	"mq_getsetattr",
	"kexec_load",
	"waitid",
	"add_key",
	"request_key",
	"keyctl",
	"ioprio_set",
	"ioprio_get",
	"inotify_init",
	"inotify_add_watch",
	"inotify_rm_watch",
	"migrate_pages",
	"openat",
	"mkdirat",
	"mknodat",
	"fchownat",
	"futimesat",
	"newfstatat",
	"unlinkat",
	"renameat",
	"linkat",
	"symlinkat",
	"readlinkat",
	"fchmodat",
	"faccessat",
	"pselect6",
	"ppoll",
	"unshare",
	"set_robust_list",
	"get_robust_list",
	"splice",
	"tee",
	"sync_file_range",
	"vmsplice",
	"move_pages",
	"utimensat",
	"epoll_pwait",
	"signalfd",
	"timerfd_create",
	"eventfd",
	"fallocate",
	"timerfd_settime",
	"timerfd_gettime",
	"accept4",
	"signalfd4",
	"eventfd2",
	"epoll_create1",
	"dup3",
	"pipe2",
	"inotify_init1",
	"preadv",
	"pwritev",
	"rt_tgsigqueueinfo",
	"perf_event_open",
	"recvmmsg",
	"fanotify_init",
	"fanotify_mark",
	"prlimit64",
	"name_to_handle_at",
	"open_by_handle_at",
	"clock_adjtime",
	"syncfs",
	"sendmmsg",
	"setns",
	"getcpu",
	"process_vm_readv",
	"process_vm_writev",
	"kcmp",
	"finit_module",
	"sched_setattr",
	"sched_getattr",
	"renameat2",
	"seccomp",
	"getrandom",
	"memfd_create",
	"kexec_file_load",
	"bpf",
	"execveat",
}

func callNameX86Family64(num int16) string {
	if num > SyscallX86MaxNum64 {
		return SyscallX86UnknownName
	}

	return syscallNumTableX86Family64[num]
}

func callNumTableIsOkX86Family64() bool {
	if (len(syscallNumTableX86Family64) == SyscallX86MaxNum64+1) &&
		syscallNumTableX86Family64[SyscallX86MaxNum64] == SyscallX86LastName64 {
		return true
	}

	return false
}

var syscallNumTableX86Family32 = [...]string{
	"restart_syscall",
	"_exit",
	"fork",
	"read",
	"write",
	"open",
	"close",
	"waitpid",
	"creat",
	"link",
	"unlink",
	"execve",
	"chdir",
	"time",
	"mknod",
	"chmod",
	"lchown",
	"break",
	"oldstat",
	"lseek",
	"getpid",
	"mount",
	"umount",
	"setuid",
	"getuid",
	"stime",
	"ptrace",
	"alarm",
	"oldfstat",
	"pause",
	"utime",
	"stty",
	"gtty",
	"access",
	"nice",
	"ftime",
	"sync",
	"kill",
	"rename",
	"mkdir",
	"rmdir",
	"dup",
	"pipe",
	"times",
	"prof",
	"brk",
	"setgid",
	"getgid",
	"signal",
	"geteuid",
	"getegid",
	"acct",
	"umount2",
	"lock",
	"ioctl",
	"fcntl",
	"mpx",
	"setpgid",
	"ulimit",
	"oldolduname",
	"umask",
	"chroot",
	"ustat",
	"dup2",
	"getppid",
	"getpgrp",
	"setsid",
	"sigaction",
	"sgetmask",
	"ssetmask",
	"setreuid",
	"setregid",
	"sigsuspend",
	"sigpending",
	"sethostname",
	"setrlimit",
	"getrlimit",
	"getrusage",
	"gettimeofday",
	"settimeofday",
	"getgroups",
	"setgroups",
	"oldselect",
	"symlink",
	"oldlstat",
	"readlink",
	"uselib",
	"swapon",
	"reboot",
	"readdir",
	"old_mmap",
	"munmap",
	"truncate",
	"ftruncate",
	"fchmod",
	"fchown",
	"getpriority",
	"setpriority",
	"profil",
	"statfs",
	"fstatfs",
	"ioperm",
	"socketcall",
	"syslog",
	"setitimer",
	"getitimer",
	"stat",
	"lstat",
	"fstat",
	"olduname",
	"iopl",
	"vhangup",
	"idle",
	"vm86old",
	"wait4",
	"swapoff",
	"sysinfo",
	"ipc",
	"fsync",
	"sigreturn",
	"clone",
	"setdomainname",
	"uname",
	"modify_ldt",
	"adjtimex",
	"mprotect",
	"sigprocmask",
	"create_module",
	"init_module",
	"delete_module",
	"get_kernel_syms",
	"quotactl",
	"getpgid",
	"fchdir",
	"bdflush",
	"sysfs",
	"personality",
	"afs_syscall",
	"setfsuid",
	"setfsgid",
	"_llseek",
	"getdents",
	"select",
	"flock",
	"msync",
	"readv",
	"writev",
	"getsid",
	"fdatasync",
	"_sysctl",
	"mlock",
	"munlock",
	"mlockall",
	"munlockall",
	"sched_setparam",
	"sched_getparam",
	"sched_setscheduler",
	"sched_getscheduler",
	"sched_yield",
	"sched_get_priority_max",
	"sched_get_priority_min",
	"sched_rr_get_interval",
	"nanosleep",
	"mremap",
	"setresuid",
	"getresuid",
	"vm86",
	"query_module",
	"poll",
	"nfsservctl",
	"setresgid",
	"getresgid",
	"prctl",
	"rt_sigreturn",
	"rt_sigaction",
	"rt_sigprocmask",
	"rt_sigpending",
	"rt_sigtimedwait",
	"rt_sigqueueinfo",
	"rt_sigsuspend",
	"pread64",
	"pwrite64",
	"chown",
	"getcwd",
	"capget",
	"capset",
	"sigaltstack",
	"sendfile",
	"getpmsg",
	"putpmsg",
	"vfork",
	"ugetrlimit",
	"mmap2",
	"truncate64",
	"ftruncate64",
	"stat64",
	"lstat64",
	"fstat64",
	"lchown32",
	"getuid32",
	"getgid32",
	"geteuid32",
	"getegid32",
	"setreuid32",
	"setregid32",
	"getgroups32",
	"setgroups32",
	"fchown32",
	"setresuid32",
	"getresuid32",
	"setresgid32",
	"getresgid32",
	"chown32",
	"setuid32",
	"setgid32",
	"setfsuid32",
	"setfsgid32",
	"pivot_root",
	"mincore",
	"madvise",
	"getdents64",
	"fcntl64",
	"unused.222", //222 - unused
	"security",   //223 - supposed to be unused too
	"gettid",
	"readahead",
	"setxattr",
	"lsetxattr",
	"fsetxattr",
	"getxattr",
	"lgetxattr",
	"fgetxattr",
	"listxattr",
	"llistxattr",
	"flistxattr",
	"removexattr",
	"lremovexattr",
	"fremovexattr",
	"tkill",
	"sendfile64",
	"futex",
	"sched_setaffinity",
	"sched_getaffinity",
	"set_thread_area",
	"get_thread_area",
	"io_setup",
	"io_destroy",
	"io_getevents",
	"io_submit",
	"io_cancel",
	"fadvise64",
	"unused.251", //251 - unused (available for reuse) was used by sys_set_zone_reclaim
	"exit_group",
	"lookup_dcookie",
	"epoll_create",
	"epoll_ctl",
	"epoll_wait",
	"remap_file_pages",
	"set_tid_address",
	"timer_create",
	"timer_settime",
	"timer_gettime",
	"timer_getoverrun",
	"timer_delete",
	"clock_settime",
	"clock_gettime",
	"clock_getres",
	"clock_nanosleep",
	"statfs64",
	"fstatfs64",
	"tgkill",
	"utimes",
	"fadvise64_64",
	"vserver",
	"mbind",
	"get_mempolicy",
	"set_mempolicy",
	"mq_open",
	"mq_unlink",
	"mq_timedsend",
	"mq_timedreceive",
	"mq_notify",
	"mq_getsetattr",
	"kexec_load",
	"waitid",
	"setaltroot", //285 - sys_setaltroot (sort of used :))
	"add_key",
	"request_key",
	"keyctl",
	"ioprio_set",
	"ioprio_get",
	"inotify_init",
	"inotify_add_watch",
	"inotify_rm_watch",
	"migrate_pages",
	"openat",
	"mkdirat",
	"mknodat",
	"fchownat",
	"futimesat",
	"fstatat64",
	"unlinkat",
	"renameat",
	"linkat",
	"symlinkat",
	"readlinkat",
	"fchmodat",
	"faccessat",
	"pselect6",
	"ppoll",
	"unshare",
	"set_robust_list",
	"get_robust_list",
	"splice",
	"sync_file_range",
	"tee",
	"vmsplice",
	"move_pages",
	"getcpu",
	"epoll_pwait",
	"utimensat",
	"signalfd",
	"timerfd_create",
	"eventfd",
	"fallocate",
	"timerfd_settime",
	"timerfd_gettime",
	"signalfd4",
	"eventfd2",
	"epoll_create1",
	"dup3",
	"pipe2",
	"inotify_init1",
	"preadv",
	"pwritev",
	"rt_tgsigqueueinfo",
	"perf_event_open",
	"recvmmsg",
	"fanotify_init",
	"fanotify_mark",
	"prlimit64",
	"name_to_handle_at",
	"open_by_handle_at",
	"clock_adjtime",
	"syncfs",
	"sendmmsg",
	"setns",
	"process_vm_readv",
	"process_vm_writev",
	"kcmp",
	"finit_module",
	"sched_setattr",
	"sched_getattr",
	"renameat2",
	"seccomp",
	"getrandom",
	"memfd_create",
	"bpf",
	"execveat",
}

func callNameX86Family32(num int16) string {
	if num > SyscallX86MaxNum32 {
		return SyscallX86UnknownName
	}

	return syscallNumTableX86Family32[num]
}

func callNumTableIsOkX86Family32() bool {
	if (len(syscallNumTableX86Family32) == SyscallX86MaxNum32+1) &&
		syscallNumTableX86Family32[SyscallX86MaxNum32] == SyscallX86LastName32 {
		return true
	}

	return false
}

var syscallNumTableArmFamily32 = map[int16]string{
	0:   "restart_syscall",
	1:   "exit",
	2:   "fork",
	3:   "read",
	4:   "write",
	5:   "open",
	6:   "close",
	8:   "creat",
	9:   "link",
	10:  "unlink",
	11:  "execve",
	12:  "chdir",
	13:  "time",
	14:  "mknod",
	15:  "chmod",
	16:  "lchown",
	19:  "lseek",
	20:  "getpid",
	21:  "mount",
	22:  "umount",
	23:  "setuid",
	24:  "getuid",
	25:  "stime",
	26:  "ptrace",
	27:  "alarm",
	29:  "pause",
	30:  "utime",
	33:  "access",
	34:  "nice",
	36:  "sync",
	37:  "kill",
	38:  "rename",
	39:  "mkdir",
	40:  "rmdir",
	41:  "dup",
	42:  "pipe",
	43:  "times",
	45:  "brk",
	46:  "setgid",
	47:  "getgid",
	49:  "geteuid",
	50:  "getegid",
	51:  "acct",
	52:  "umount2",
	54:  "ioctl",
	55:  "fcntl",
	57:  "setpgid",
	60:  "umask",
	61:  "chroot",
	62:  "ustat",
	63:  "dup2",
	64:  "getppid",
	65:  "getpgrp",
	66:  "setsid",
	67:  "sigaction",
	70:  "setreuid",
	71:  "setregid",
	72:  "sigsuspend",
	73:  "sigpending",
	74:  "sethostname",
	75:  "setrlimit",
	76:  "getrlimit",
	77:  "getrusage",
	78:  "gettimeofday",
	79:  "settimeofday",
	80:  "getgroups",
	81:  "setgroups",
	82:  "select",
	83:  "symlink",
	85:  "readlink",
	86:  "uselib",
	87:  "swapon",
	88:  "reboot",
	89:  "readdir",
	90:  "mmap",
	91:  "munmap",
	92:  "truncate",
	93:  "ftruncate",
	94:  "fchmod",
	95:  "fchown",
	96:  "getpriority",
	97:  "setpriority",
	99:  "statfs",
	100: "fstatfs",
	102: "socketcall",
	103: "syslog",
	104: "setitimer",
	105: "getitimer",
	106: "stat",
	107: "lstat",
	108: "fstat",
	111: "vhangup",
	113: "syscall",
	114: "wait4",
	115: "swapoff",
	116: "sysinfo",
	117: "ipc",
	118: "fsync",
	119: "sigreturn",
	120: "clone",
	121: "setdomainname",
	122: "uname",
	124: "adjtimex",
	125: "mprotect",
	126: "sigprocmask",
	128: "init_module",
	129: "delete_module",
	131: "quotactl",
	132: "getpgid",
	133: "fchdir",
	134: "bdflush",
	135: "sysfs",
	136: "personality",
	138: "setfsuid",
	139: "setfsgid",
	140: "_llseek",
	141: "getdents",
	142: "_newselect",
	143: "flock",
	144: "msync",
	145: "readv",
	146: "writev",
	147: "getsid",
	148: "fdatasync",
	149: "_sysctl",
	150: "mlock",
	151: "munlock",
	152: "mlockall",
	153: "munlockall",
	154: "sched_setparam",
	155: "sched_getparam",
	156: "sched_setscheduler",
	157: "sched_getscheduler",
	158: "sched_yield",
	159: "sched_get_priority_max",
	160: "sched_get_priority_min",
	161: "sched_rr_get_interval",
	162: "nanosleep",
	163: "mremap",
	164: "setresuid",
	165: "getresuid",
	168: "poll",
	169: "nfsservctl",
	170: "setresgid",
	171: "getresgid",
	172: "prctl",
	173: "rt_sigreturn",
	174: "rt_sigaction",
	175: "rt_sigprocmask",
	176: "rt_sigpending",
	177: "rt_sigtimedwait",
	178: "rt_sigqueueinfo",
	179: "rt_sigsuspend",
	180: "pread64",
	181: "pwrite64",
	182: "chown",
	183: "getcwd",
	184: "capget",
	185: "capset",
	186: "sigaltstack",
	187: "sendfile",
	190: "vfork",
	191: "ugetrlimit",
	192: "mmap2",
	193: "truncate64",
	194: "ftruncate64",
	195: "stat64",
	196: "lstat64",
	197: "fstat64",
	198: "lchown32",
	199: "getuid32",
	200: "getgid32",
	201: "geteuid32",
	202: "getegid32",
	203: "setreuid32",
	204: "setregid32",
	205: "getgroups32",
	206: "setgroups32",
	207: "fchown32",
	208: "setresuid32",
	209: "getresuid32",
	210: "setresgid32",
	211: "getresgid32",
	212: "chown32",
	213: "setuid32",
	214: "setgid32",
	215: "setfsuid32",
	216: "setfsgid32",
	217: "getdents64",
	218: "pivot_root",
	219: "mincore",
	220: "madvise",
	221: "fcntl64",
	224: "gettid",
	225: "readahead",
	226: "setxattr",
	227: "lsetxattr",
	228: "fsetxattr",
	229: "getxattr",
	230: "lgetxattr",
	231: "fgetxattr",
	232: "listxattr",
	233: "llistxattr",
	234: "flistxattr",
	235: "removexattr",
	236: "lremovexattr",
	237: "fremovexattr",
	238: "tkill",
	239: "sendfile64",
	240: "futex",
	241: "sched_setaffinity",
	242: "sched_getaffinity",
	243: "io_setup",
	244: "io_destroy",
	245: "io_getevents",
	246: "io_submit",
	247: "io_cancel",
	248: "exit_group",
	249: "lookup_dcookie",
	250: "epoll_create",
	251: "epoll_ctl",
	252: "epoll_wait",
	253: "remap_file_pages",
	256: "set_tid_address",
	257: "timer_create",
	258: "timer_settime",
	259: "timer_gettime",
	260: "timer_getoverrun",
	261: "timer_delete",
	262: "clock_settime",
	263: "clock_gettime",
	264: "clock_getres",
	265: "clock_nanosleep",
	266: "statfs64",
	267: "fstatfs64",
	268: "tgkill",
	269: "utimes",
	270: "arm_fadvise64_64",
	271: "pciconfig_iobase",
	272: "pciconfig_read",
	273: "pciconfig_write",
	274: "mq_open",
	275: "mq_unlink",
	276: "mq_timedsend",
	277: "mq_timedreceive",
	278: "mq_notify",
	279: "mq_getsetattr",
	280: "waitid",
	281: "socket",
	282: "bind",
	283: "connect",
	284: "listen",
	285: "accept",
	286: "getsockname",
	287: "getpeername",
	288: "socketpair",
	289: "send",
	290: "sendto",
	291: "recv",
	292: "recvfrom",
	293: "shutdown",
	294: "setsockopt",
	295: "getsockopt",
	296: "sendmsg",
	297: "recvmsg",
	298: "semop",
	299: "semget",
	300: "semctl",
	301: "msgsnd",
	302: "msgrcv",
	303: "msgget",
	304: "msgctl",
	305: "shmat",
	306: "shmdt",
	307: "shmget",
	308: "shmctl",
	309: "add_key",
	310: "request_key",
	311: "keyctl",
	312: "semtimedop",
	313: "vserver",
	314: "ioprio_set",
	315: "ioprio_get",
	316: "inotify_init",
	317: "inotify_add_watch",
	318: "inotify_rm_watch",
	319: "mbind",
	320: "get_mempolicy",
	321: "set_mempolicy",
	322: "openat",
	323: "mkdirat",
	324: "mknodat",
	325: "fchownat",
	326: "futimesat",
	327: "fstatat64",
	328: "unlinkat",
	329: "renameat",
	330: "linkat",
	331: "symlinkat",
	332: "readlinkat",
	333: "fchmodat",
	334: "faccessat",
	335: "pselect6",
	336: "ppoll",
	337: "unshare",
	338: "set_robust_list",
	339: "get_robust_list",
	340: "splice",
	341: "sync_file_range2",
	342: "tee",
	343: "vmsplice",
	344: "move_pages",
	345: "getcpu",
	346: "epoll_pwait",
	347: "kexec_load",
	348: "utimensat",
	349: "signalfd",
	350: "timerfd_create",
	351: "eventfd",
	352: "fallocate",
	353: "timerfd_settime",
	354: "timerfd_gettime",
	355: "signalfd4",
	356: "eventfd2",
	357: "epoll_create1",
	358: "dup3",
	359: "pipe2",
	360: "inotify_init1",
	361: "preadv",
	362: "pwritev",
	363: "rt_tgsigqueueinfo",
	364: "perf_event_open",
	365: "recvmmsg",
	366: "accept4",
	367: "fanotify_init",
	368: "fanotify_mark",
	369: "prlimit64",
	370: "name_to_handle_at",
	371: "open_by_handle_at",
	372: "clock_adjtime",
	373: "syncfs",
	374: "sendmmsg",
	375: "setns",
	376: "process_vm_readv",
	377: "process_vm_writev",
}

func callNameArmFamily32(num int16) string {
	if num > SyscallArmMaxNum32 {
		return SyscallArmUnknownName
	}

	return syscallNumTableArmFamily32[num]
}

func callNumTableIsOkArmFamily32() bool {
	if (len(syscallNumTableArmFamily32) == SyscallArmMaxNum32+1) &&
		syscallNumTableArmFamily32[SyscallArmMaxNum32] == SyscallArmLastName32 {
		return true
	}

	return false
}
